==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/datareplication/kotlin/outputs/HyperVToAzStackHCIProtectedNicPropertiesResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datareplication.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 * HyperVToAzStackHCI NIC properties.
 * @property macAddress Gets or sets the NIC mac address.
 * @property networkName Gets or sets the network name.
 * @property nicId Gets or sets the NIC Id.
 * @property selectionTypeForFailover Gets or sets the selection type of the NIC.
 * @property targetNetworkId Gets or sets the target network Id within AzStackHCI Cluster.
 * @property testNetworkId Gets or sets the target test network Id within AzStackHCI Cluster.
 */
public data class HyperVToAzStackHCIProtectedNicPropertiesResponse(
    public val macAddress: String,
    public val networkName: String,
    public val nicId: String,
    public val selectionTypeForFailover: String,
    public val targetNetworkId: String,
    public val testNetworkId: String,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.datareplication.outputs.HyperVToAzStackHCIProtectedNicPropertiesResponse):
            HyperVToAzStackHCIProtectedNicPropertiesResponse =
            HyperVToAzStackHCIProtectedNicPropertiesResponse(
                macAddress = javaType.macAddress(),
                networkName = javaType.networkName(),
                nicId = javaType.nicId(),
                selectionTypeForFailover = javaType.selectionTypeForFailover(),
                targetNetworkId = javaType.targetNetworkId(),
                testNetworkId = javaType.testNetworkId(),
            )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/datareplication/kotlin/outputs/HyperVToAzStackHCIProtectedNicPropertiesResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datareplication.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 * HyperVToAzStackHCI NIC properties.
 * @property macAddress Gets or sets the NIC mac address.
 * @property networkName Gets or sets the network name.
 * @property nicId Gets or sets the NIC Id.
 * @property selectionTypeForFailover Gets or sets the selection type of the NIC.
 * @property targetNetworkId Gets or sets the target network Id within AzStackHCI Cluster.
 * @property testNetworkId Gets or sets the target test network Id within AzStackHCI Cluster.
 */
public data class HyperVToAzStackHCIProtectedNicPropertiesResponse(
    public val macAddress: String,
    public val networkName: String,
    public val nicId: String,
    public val selectionTypeForFailover: String,
    public val targetNetworkId: String,
    public val testNetworkId: String,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.datareplication.outputs.HyperVToAzStackHCIProtectedNicPropertiesResponse): HyperVToAzStackHCIProtectedNicPropertiesResponse =
            HyperVToAzStackHCIProtectedNicPropertiesResponse(
                macAddress = javaType.macAddress(),
                networkName = javaType.networkName(),
                nicId = javaType.nicId(),
                selectionTypeForFailover = javaType.selectionTypeForFailover(),
                targetNetworkId = javaType.targetNetworkId(),
                testNetworkId = javaType.testNetworkId(),
            )
    }
}
